GEneral PREprocessing Framework for TEXT (gepref_text)
======================================================

The ``gepref_text`` library is an implementation of the `gepref framework <https://github.com/juselara1/gepref>`_ for text preprocessing. It allows to easily build preprocessing pipelines from ready-to-use or custom components.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   usage
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
